@@ -3,13 +3,23 @@ package Array::Iterator;
 use strict;
 use warnings;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-21'; # DATE
-our $DIST = 'Array-Iterator'; # DIST
-our $VERSION = '0.132'; # VERSION
+# AUTHORITY
+# DATE
+# DIST
+
+=head1 NAME
+
+Array::Iterator - A simple class for iterating over Perl arrays
+
+=head1 VERSION
+
+Version 0.133
+
+=cut
+
+our $VERSION = '0.133';
 
 ### constructor
-
 sub new {
 	my ($_class, @array) = @_;
 	(@array)
@@ -167,21 +177,9 @@ sub get_length {
 sub getLength { my $self = shift; $self->get_length(@_) }
 
 1;
-# ABSTRACT: (ADOPTME) A simple class for iterating over Perl arrays
+#ABSTRACT: (ADOPTME) A simple class for iterating over Perl arrays
 
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Array::Iterator - (ADOPTME) A simple class for iterating over Perl arrays
-
-=head1 VERSION
-
-This document describes version 0.132 of Array::Iterator (from Perl distribution Array-Iterator), released on 2023-11-21.
+=for Pod::Coverage .+
 
 =head1 SYNOPSIS
 
@@ -231,85 +229,6 @@ no attempt is made to enforce this (although I will if I can find an efficient
 means of doing so). This class only intends to provide a clear and simple
 means of generic iteration, nothing more (yet).
 
-=for Pod::Coverage .+
-
-=head1 TO DO
-
-=over 4
-
-=item Improve BiDirectional Test suite
-
-I want to test the back and forth a little more, make sure they work well with
-one another.
-
-=item Other Iterators
-
-Array::Iterator::BiDirectional::Circular, Array::Iterator::Skipable and
-Array::Iterator::BiDirectional::Skipable are just a few ideas I have had. I am going
-to hold off for now until I am sure they are actually useful.
-
-=back
-
-=head1 OTHER ITERATOR MODULES
-
-There are a number of modules on CPAN with the word Iterator in them. Most of them are
-actually iterators included inside other modules, and only really useful within that
-parent modules context. There are however some other modules out there that are just
-for pure iteration. I have provided a list below of the ones I have found, if perhaps
-you don't happen to like the way I do it.
-
-=over 4
-
-=item B<Tie::Array::Iterable>
-
-This module ties the array, something we do not do. But it also makes an attempt to
-account for, and allow the array to be changed during iteration. It accomplishes this
-control because the underlying array is tied. As we all know, tie-ing things can be a
-performance issue, but if you need what this module provides, then it will likely be
-an acceptable compromise. Array::Iterator makes no attempt to deal with this mid-iteration
-manipulation problem. In fact it is recommended to not alter your array with Array::Iterator,
-and if possible we will enforce this in later versions.
-
-=item B<Data::Iter>
-
-This module allows for simple iteration over both hashes and arrays. It does it by
-importing several functions which can be used to loop over either type (hash or array)
-in the same way. It is an interesting module, it differs from Array::Iterator in
-paradigm (Array::Iterator is more OO) as well as in intent.
-
-=item B<Class::Iterator>
-
-This is essentially a wrapper around a closure based iterator. This method can be very
-flexible, but at times is difficult to manage due to the inherent complexity of using
-closures. I actually was a closure-as-iterator fan for a while, but eventually moved
-away from it in favor of the more plain vanilla means of iteration, like that found
-Array::Iterator.
-
-=item B<Class::Iter>
-
-This is part of the Class::Visitor module, and is a Visitor and Iterator extensions to
-Class::Template. Array::Iterator is a standalone module not associated with others.
-
-=item B<Data::Iterator::EasyObj>
-
-Data::Iterator::EasyObj makes your array of arrays into iterator objects. It also has
-the ability to further nest additional data structures including Data::Iterator::EasyObj
-objects. Array::Iterator is one dimensional only, and does not attempt to do many of
-the more advanced features of this module.
-
-=back
-
-=head1 ACKNOWLEDGEMENTS
-
-=over 4
-
-=item Thanks to Hugo Cornelis for pointing out a bug in C<peek()>
-
-=item Thanks to Phillip Moore for providing the patch to allow single element iteration
-through the hash-ref constructor parameter.
-
-=back
-
 =head1 METHODS
 
 =head2 Public Methods
@@ -437,13 +356,22 @@ of C<$index>.
 
 =back
 
-=head1 HOMEPAGE
+=head1 TO DO
 
-Please visit the project's homepage at L<https://metacpan.org/release/Array-Iterator>.
+=over 4
 
-=head1 SOURCE
+=item Improve BiDirectional Test suite
 
-Source repository is at L<https://github.com/perlancar/perl-Array-Iterator>.
+I want to test the back and forth a little more, make sure they work well with
+one another.
+
+=item Other Iterators
+
+Array::Iterator::BiDirectional::Circular, Array::Iterator::Skipable and
+Array::Iterator::BiDirectional::Skipable are just a few ideas I have had. I am going
+to hold off for now until I am sure they are actually useful.
+
+=back
 
 =head1 SEE ALSO
 
@@ -470,67 +398,70 @@ The Design Patterns book by the Gang of Four, specifically the Iterator pattern.
 
 Some of the interface for this class is based upon the Java Iterator interface.
 
-=head1 AUTHOR
+=head1 OTHER ITERATOR MODULES
 
-perlancar <perlancar@cpan.org>
+There are a number of modules on CPAN with the word Iterator in them. Most of them are
+actually iterators included inside other modules, and only really useful within that
+parent modules context. There are however some other modules out there that are just
+for pure iteration. I have provided a list below of the ones I have found, if perhaps
+you don't happen to like the way I do it.
+
+=over 4
+
+=item B<Tie::Array::Iterable>
+
+This module ties the array, something we do not do. But it also makes an attempt to
+account for, and allow the array to be changed during iteration. It accomplishes this
+control because the underlying array is tied. As we all know, tie-ing things can be a
+performance issue, but if you need what this module provides, then it will likely be
+an acceptable compromise. Array::Iterator makes no attempt to deal with this mid-iteration
+manipulation problem. In fact it is recommended to not alter your array with Array::Iterator,
+and if possible we will enforce this in later versions.
+
+=item B<Data::Iter>
+
+This module allows for simple iteration over both hashes and arrays. It does it by
+importing several functions which can be used to loop over either type (hash or array)
+in the same way. It is an interesting module, it differs from Array::Iterator in
+paradigm (Array::Iterator is more OO) as well as in intent.
+
+=item B<Class::Iterator>
+
+This is essentially a wrapper around a closure based iterator. This method can be very
+flexible, but at times is difficult to manage due to the inherent complexity of using
+closures. I actually was a closure-as-iterator fan for a while, but eventually moved
+away from it in favor of the more plain vanilla means of iteration, like that found
+Array::Iterator.
+
+=item B<Class::Iter>
+
+This is part of the Class::Visitor module, and is a Visitor and Iterator extensions to
+Class::Template. Array::Iterator is a standalone module not associated with others.
+
+=item B<Data::Iterator::EasyObj>
+
+Data::Iterator::EasyObj makes your array of arrays into iterator objects. It also has
+the ability to further nest additional data structures including Data::Iterator::EasyObj
+objects. Array::Iterator is one dimensional only, and does not attempt to do many of
+the more advanced features of this module.
+
+=back
+
+=head1 ACKNOWLEDGEMENTS
+
+=over 4
+
+=item Thanks to Hugo Cornelis for pointing out a bug in C<peek()>
+
+=item Thanks to Phillip Moore for providing the patch to allow single element iteration
+through the hash-ref constructor parameter.
+
+=back
 
 =head1 ORIGINAL AUTHOR
 
 stevan little, E<lt>stevan@iinteractive.comE<gt>
 
-=head1 CONTRIBUTORS
-
-=for stopwords Alexey Surikov Florian Schlichting Mohammad S Anwar Neil Bowers Steven Haryanto
-
-=over 4
-
-=item *
-
-Alexey Surikov <ksurent@gmail.com>
-
-=item *
-
-Florian Schlichting <fsfs@debian.org>
-
-=item *
-
-Mohammad S Anwar <mohammad.anwar@yahoo.com>
-
-=item *
-
-Neil Bowers <neil@bowers.com>
-
-=item *
-
-Steven Haryanto <stevenharyanto@gmail.com>
-
-=back
-
-=head1 CONTRIBUTING
-
-
-To contribute, you can send patches by email/via RT, or send pull requests on
-GitHub.
-
-Most of the time, you don't need to build the distribution yourself. You can
-simply modify the code, then test via:
-
- % prove -l
-
-If you want to build the distribution (e.g. to try to install it locally on your
-system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
-L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
-that are considered a bug and can be reported to me.
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2023, 2021, 2017, 2013, 2012, 2011 by perlancar <perlancar@cpan.org>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 ORIGINAL COPYRIGHT AND LICENSE
 
 Copyright 2004, 2005 by Infinity Interactive, Inc.
@@ -540,12 +471,40 @@ L<http://www.iinteractive.com>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=head1 BUGS
+=head1 SUPPORT
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Array-Iterator>
+This module is provided as-is without any warranty.
 
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
+Please report any bugs or feature requests to C<bug-array-iterator at rt.cpan.org>,
+or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Array-Iterator>.
+I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Array::Iterator
+
+You can also look for information at:
+
+=over 4
+
+=item * MetaCPAN
+
+L<https://metacpan.org/dist/Array-Iterator>
+
+=item * RT: CPAN's request tracker
+
+L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Array-Iterator>
+
+=item * CPAN Testers' Matrix
+
+L<http://matrix.cpantesters.org/?dist=Array-Iterator>
+
+=item * CPAN Testers Dependencies
+
+L<http://deps.cpantesters.org/?module=Array::Iterator>
+
+=back
 
 =cut
